pub struct Error {
pub message: String,
pub file_name: String,
pub line: usize,
pub column: usize,
}Expand description
An error produced while reading, writing, or formatting RDL.
Fields
message: StringHuman-readable description of what went wrong.
file_name: StringName of the file in which the error occurred, if known.
line: usizeLine number of the error, or 0 if not applicable.
column: usizeZero-based column number of the error, or 0 if not applicable.
Implementations