Reader

Struct Reader 

pub struct Reader { /* private fields */ }
Builder that compiles RDL files into .winmd metadata.

Implementations

Source

impl Reader

pub fn new() -> Self

Creates a new builder with default options.

pub fn input(&mut self, input: impl AsRef<Path>) -> &mut Self

Adds an input .rdl file or directory.

pub fn input_text(&mut self, input: &str) -> &mut Self

Adds inline RDL source text to compile instead of a file on disk.

pub fn input_texts<I, S>(&mut self, inputs: I) -> &mut Self
where I: IntoIterator<Item = S>, S: AsRef<str>,

Adds inline RDL source texts to compile instead of files on disk.

pub fn reference(&mut self, input: impl AsRef<Path>) -> &mut Self

Adds a .winmd reference file or directory.

pub fn references<I, S>(&mut self, inputs: I) -> &mut Self
where I: IntoIterator<Item = S>, S: AsRef<Path>,

Adds multiple .winmd reference files or directories.

pub fn reference_bytes(&mut self, input: &[u8]) -> &mut Self

Adds a .winmd reference from memory.

pub fn reference_byte_sets<I, B>(&mut self, inputs: I) -> &mut Self
where I: IntoIterator<Item = B>, B: AsRef<[u8]>,

Adds .winmd references from memory.

pub fn reference_default(&mut self) -> &mut Self

Adds the default Windows metadata references.

pub fn inputs<I, S>(&mut self, inputs: I) -> &mut Self
where I: IntoIterator<Item = S>, S: AsRef<Path>,

Adds multiple input .rdl files or directories.

pub fn output(&mut self, output: impl AsRef<Path>) -> &mut Self

Sets the output .winmd file path.

pub fn write(&self) -> Result<(), Error>

Compiles the inputs and writes the .winmd to the configured output.