pub struct Reader { /* private fields */ }Expand description
Builder that compiles RDL files into .winmd metadata.
Implementations
Sourceimpl Reader
impl Reader
Sourcepub fn input(&mut self, input: impl AsRef<Path>) -> &mut Self
pub fn input(&mut self, input: impl AsRef<Path>) -> &mut Self
Adds an input .rdl file or directory.
Sourcepub fn input_text(&mut self, input: &str) -> &mut Self
pub fn input_text(&mut self, input: &str) -> &mut Self
Adds inline RDL source text to compile instead of a file on disk.
Sourcepub fn input_texts<I, S>(&mut self, inputs: I) -> &mut Self
pub fn input_texts<I, S>(&mut self, inputs: I) -> &mut Self
Adds inline RDL source texts to compile instead of files on disk.
Sourcepub fn reference(&mut self, input: impl AsRef<Path>) -> &mut Self
pub fn reference(&mut self, input: impl AsRef<Path>) -> &mut Self
Adds a .winmd reference file or directory.
Sourcepub fn references<I, S>(&mut self, inputs: I) -> &mut Self
pub fn references<I, S>(&mut self, inputs: I) -> &mut Self
Adds multiple .winmd reference files or directories.
Sourcepub fn reference_bytes(&mut self, input: &[u8]) -> &mut Self
pub fn reference_bytes(&mut self, input: &[u8]) -> &mut Self
Adds a .winmd reference from memory.
Sourcepub fn reference_byte_sets<I, B>(&mut self, inputs: I) -> &mut Self
pub fn reference_byte_sets<I, B>(&mut self, inputs: I) -> &mut Self
Adds .winmd references from memory.
Sourcepub fn reference_default(&mut self) -> &mut Self
pub fn reference_default(&mut self) -> &mut Self
Adds the default Windows metadata references.
Sourcepub fn inputs<I, S>(&mut self, inputs: I) -> &mut Self
pub fn inputs<I, S>(&mut self, inputs: I) -> &mut Self
Adds multiple input .rdl files or directories.